import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';

typedef void BannerViewCreatedCallback(BannerController controller);

class FlutterWortise {
  static const MethodChannel _channel = const MethodChannel('flutter_wortise');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
}

class BannerAd extends StatefulWidget {
  const BannerAd({
    Key key,
    this.onBannerViewCreated,
  }) : super(key: key);
  @override
  _BannerAdState createState() => _BannerAdState();

  final BannerViewCreatedCallback onBannerViewCreated;
}

class _BannerAdState extends State<BannerAd> {

  @override
  Widget build(BuildContext context) {
    return defaultTargetPlatform == TargetPlatform.android ?
    AndroidView(
      viewType: 'org.devsin.flutter_wortise/bannerad',
      onPlatformViewCreated: _onPlatformViewCreated,
    ) : Text('$defaultTargetPlatform not supported yet.');
  }

  void _onPlatformViewCreated(int id) {
    if (widget.onBannerViewCreated == null) {
      return;
    }
    widget.onBannerViewCreated(new BannerController._(id));
  }
}

class BannerController {
  final MethodChannel _channel;

  BannerController._(int id)
      : _channel = new MethodChannel('org.devsin.flutter_wortise/bannerad_$id');

  Future<void> loadAd(String adId){
    assert(adId != null);
    return _channel.invokeMethod('loadAd', adId);
  }

  Future<void> pauseAd(){
    return _channel.invokeMethod('pauseAd');
  }

  Future<void> resumeAd(){
    return _channel.invokeMethod('resumeAd');
  }
}

class WortiseSdk {
  static MethodChannel _channel;

  static final WortiseSdk _instance = WortiseSdk._();

  static WortiseSdk get instance => _instance;

  WortiseSdk._(){
    _channel = new MethodChannel('flutter_wortise');
  }

  Future<void> initialize(String apiKey){
    assert(apiKey != null);
    return _channel.invokeMethod('initialize', apiKey);
  }

  Future<void> stop(){
    return _channel.invokeMethod('stop');
  }
}
